==> dde-daemon_6.0.44.tar.xz: BUILD/misc/ts/org.deepin.dde.fprintd.policy/policy_ug.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ug" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="org.deepin.dde.fprintd.enroll!message" line="0"/>
			<source>Authentication is required to add fingerprint password</source>
			<translation>بارماق  ئىزى  قوشۇش ئۈچۈن  سالاھىيەت دەلىىللەڭ </translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.enroll!description" line="0"/>
			<source>Add fingerprint password</source>
			<translation>بارماق ئىزى پارولى قوشۇش</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.delete-enrolled-fingers!message" line="0"/>
			<source>Authentication is required to clear fingerprint passwords</source>
			<translation>بارماق ئىزىنى ئېلىۋېتىش دەلىللەشنى تەلەپ قىلىدۇ</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.delete-enrolled-fingers!description" line="0"/>
			<source>Clear fingerprint passwords</source>
			<translation>بارماق ئىزى پارولىنى ئېلىۋېتىش</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.rename-enrolled-finger!message" line="0"/>
			<source>Authentication is required to rename fingerprint password</source>
			<translation>بارماق  ئىزى نامىنى ئۆزگەرتىش ئۈچۈن  سالاھىيەت دەلىىللەڭ </translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.rename-enrolled-finger!description" line="0"/>
			<source>Rename fingerprint password</source>
			<translation>بارماق ئىزى پارولىنىڭ نامىنى ئۆزگەرتىش</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.manager!message" line="0"/>
			<source>Password is required to perform this action</source>
			<translation>بۇ مەشغۇلاتنى قىلىش ئۈچۈن پارول كىرگۈزۈڭ</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.manager!description" line="0"/>
			<source>Manage fingerprint passwords</source>
			<translation>بارماق ئىزى پارولىنى باشقۇرۇش</translation>
		</message>
	</context>
</TS>

==> dde-daemon_6.1.32.tar.xz: BUILD/misc/ts/org.deepin.dde.fprintd.policy/policy_ug.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ug" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="org.deepin.dde.fprintd.enroll!message" line="0"/>
			<source>Authentication is required to add fingerprint password</source>
			<translation>بارماق ئىزىنى قوشۇش دەلىللەشنى تەلەپ قىلىدۇ</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.enroll!description" line="0"/>
			<source>Add fingerprint password</source>
			<translation>بارماق ئىزى پارولى قوشۇڭ</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.delete-enrolled-fingers!message" line="0"/>
			<source>Authentication is required to clear fingerprint passwords</source>
			<translation>بارماق ئىزىنى ئېلىۋېتىش دەلىللەشنى تەلەپ قىلىدۇ</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.delete-enrolled-fingers!description" line="0"/>
			<source>Clear fingerprint passwords</source>
			<translation>بارماق ئىزى پارولىنى ئېلىۋېتىش</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.rename-enrolled-finger!message" line="0"/>
			<source>Authentication is required to rename fingerprint password</source>
			<translation>بارماق ئىزىنىنىڭ نامىنى ئۆزگەرتىش دەلىللەشنى تەلەپ قىلىدۇ</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.rename-enrolled-finger!description" line="0"/>
			<source>Rename fingerprint password</source>
			<translation>بارماق ئىزى پارولىنىڭ نامىنى ئۆزگەرتىش</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.manager!message" line="0"/>
			<source>Password is required to perform this action</source>
			<translation>بۇ مەشغۇلاتنى قىلىش ئۈچۈن پارول كىرگۈزۈڭ</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.fprintd.manager!description" line="0"/>
			<source>Manage fingerprint passwords</source>
			<translation>بارماق ئىزى پارولىنى باشقۇرۇش</translation>
		</message>
	</context>
</TS>
